/**
 * Selects the points of each series selected by the *selector*, which can be
 * specified either as a function which receives as input the index of the
 * series, the shorthand “first” or “last”, or as a {*key*: *value*} object with
 * exactly one *key* being the name of a channel and the *value* being a
 * function which receives as input the index of the series and the channel
 * values. The *value* may alternatively be specified as the shorthand “min” and
 * “max” which respectively select the minimum and maximum points for the
 * specified channel.
 *
 * For example, to select the point within each series that is the closest to
 * the median of the *y* channel:
 *
 * ```js
 * Plot.select({
 *   y: (I, V) => {
 *     const median = d3.median(I, i => V[i]);
 *     const i = d3.least(I, i => Math.abs(V[i] - median));
 *     return [i];
 *   }
 * }, {
 *   x: "year",
 *   y: "revenue",
 *   fill: "format"
 * })
 * ```
 *
 * To pick three points at random in each series:
 *
 * ```js
 * Plot.select(I => d3.shuffle(I.slice()).slice(0, 3), {z: "year", ...})
 * ```
 *
 * To pick the point in each city with the highest temperature:
 *
 * ```js
 * Plot.select({fill: "max"}, {x: "date", y: "city", fill: "temperature", z: "city"})
 * ```
 */
export function select(selector: any, options?: {}): {
    transform: any;
    sort?: any;
};
/**
 * Selects the first point of each series according to input order.
 */
export function selectFirst(options: any): {
    transform: any;
    sort?: any;
};
/**
 * Selects the last point of each series according to input order.
 */
export function selectLast(options: any): {
    transform: any;
    sort?: any;
};
/**
 * Selects the leftmost point of each series.
 */
export function selectMinX(options: any): {
    transform: any;
    sort?: any;
};
/**
 * Selects the lowest point of each series.
 */
export function selectMinY(options: any): {
    transform: any;
    sort?: any;
};
/**
 * Selects the rightmost point of each series.
 */
export function selectMaxX(options: any): {
    transform: any;
    sort?: any;
};
/**
 * Selects the highest point of each series.
 */
export function selectMaxY(options: any): {
    transform: any;
    sort?: any;
};
